==> okteta_0.25.4.orig.tar.xz: okteta-0.25.4/kasten/core/io/filesystem/bytearrayrawfileconnectjob.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYRAWFILECONNECTJOB_H
#define BYTEARRAYRAWFILECONNECTJOB_H

// Kasten core
#include <kasten/abstractfilesystemconnectjob.h>

namespace Kasten {

class ByteArrayRawFileSynchronizer;
class ByteArrayDocument;
// class ByteArrayRawFileWriteThread;

class ByteArrayRawFileConnectJob : public AbstractFileSystemConnectJob
{
    Q_OBJECT

public:
    ByteArrayRawFileConnectJob(ByteArrayRawFileSynchronizer* synchronizer, AbstractDocument* document,
                               const QUrl& url, AbstractModelSynchronizer::ConnectOption option);
    ~ByteArrayRawFileConnectJob() override;

protected: // AbstractFileSystemLoadJob API
    void startConnectWithFile() override;

protected Q_SLOTS:
//     void onDataPulled();

protected:
//     ByteArrayRawFileWriteThread *mWriteThread;
};

}

#endif

==> okteta-4.13.0.tar.xz: okteta-4.13.0/kasten/core/io/filesystem/bytearrayrawfileconnectjob.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYRAWFILECONNECTJOB_H
#define BYTEARRAYRAWFILECONNECTJOB_H

// Kasten core
#include <abstractfilesystemconnectjob.h>


namespace Kasten2
{

class ByteArrayRawFileSynchronizer;
class ByteArrayDocument;
// class ByteArrayRawFileWriteThread;

class ByteArrayRawFileConnectJob : public AbstractFileSystemConnectJob
{
  Q_OBJECT

  public:
    ByteArrayRawFileConnectJob( ByteArrayRawFileSynchronizer *synchronizer, AbstractDocument* document,
                                const KUrl& url, AbstractModelSynchronizer::ConnectOption option );
    virtual ~ByteArrayRawFileConnectJob();

  protected: // AbstractFileSystemLoadJob API
    virtual void startConnectWithFile();

  protected Q_SLOTS:
//     void onDataPulled();

  protected:
//     ByteArrayRawFileWriteThread *mWriteThread;
};

}

#endif
